@@ -28,7 +28,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: joint-chains.c 753 2007-06-15 18:17:57Z beerli $
+$Id: joint-chains.c 886 2007-08-18 03:09:50Z beerli $
 */
 
 #include "migration.h"
@@ -52,7 +52,7 @@ create_multiapg0 (MYREAL *apg0, nr_fmt * nr, long rep, long locus)
     // for each tree summary calculate the Sum over replicates
     for (g = 0; g < nr->world->atl[rep][locus].T; g++)
     {
-        tmpmax = -DBL_MAX;
+        tmpmax = -MYREAL_MAX;
         for (r = nr->repstart; r < nr->repstop; r++)
         {
             tmp[r] = -reps +
