@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1331 2008-07-31 18:55:29Z beerli $*/
+/* $Id: main.c 1450 2008-10-22 02:40:52Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -783,120 +783,108 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
   long maxreplicate;
   long treefilepos;
 #ifdef MPI
-  //#ifdef MPIREPLICANT
-  //    MPI_Status status;		// contains status used in MPI_Recv
   MPI_Request *irequests;	// contains requests generated in MPI_Isend
   MPI_Status *istatus;		// conatins stata from MPI_Wait_any
   long minnodes;
-  //    long sent;			// counter for the array irequests of the MPI_Isend requests
-  //#endif
-    long *twolongs;		// message sent to workers contains locus and replicate number
-                        //int          *ranks;
-                        //MPI_Group worldgroup, locigroup;
-    if (myID < data->loci + 1)
-        color = 1;
-    else
-        color = MPI_UNDEFINED;
+  long *twolongs;		// message sent to workers contains locus and replicate number
+  
+  if (myID < data->loci + 1)
+    color = 1;
+  else
+    color = MPI_UNDEFINED;
+  
+  twolongs = (long *) mycalloc (TWO, sizeof (long));
     
-    twolongs = (long *) mycalloc (TWO, sizeof (long));
-#endif
-    
-#ifdef MPI
-    
-    if (myID == MASTER)
+  if (myID == MASTER)
     {
 #endif
-        get_data (data->infile, data, options);
+      get_data (data->infile, data, options);
 #ifdef MPI
-        
-        //        printf("%i > finished data reading\n", myID);
-        broadcast_data_master (data, options);
-        if (numcpu == 1)
+      //        printf("%i > finished data reading\n", myID);
+      if (numcpu == 1)
         {
-            error
+	  error
             ("This program was compiled to use a parallel computer\n and you tried to run it on only a single node.\nThis will not work because it uses a \n\"single_master-many_worker\" architecture \nand needs at least TWO nodes\n");
         }
-    }
-    else
+      broadcast_data_master (data, options);
+    } /*end of myID==MASTER loop for MPI*/
+  else
     {
-        broadcast_data_worker (data, options);
+      broadcast_data_worker (data, options);
     }
-    //MPI_Comm_dup(comm_world, &comm_all_worlds);
-    //MPI_Comm_rank(comm_world, &myID);
 #endif
-    set_plot (options);
-    EARTH->cold = TRUE; // this is the cold chain when we use heating, the hotter chains have FALSE
-    init_world (EARTH, data, options);
-    set_meanmu(EARTH,options);
-    if(EARTH->cold)
-      single_chain_var (EARTH, 0, &var, NULL, NULL);
-
+  set_plot (options);
+  EARTH->cold = TRUE; // this is the cold chain when we use heating, the hotter chains have FALSE
+  init_world (EARTH, data, options);
+  set_meanmu(EARTH,options);
+  if(EARTH->cold)
+    single_chain_var (EARTH, 0, &var, NULL, NULL);
+  
 #ifdef NEXUSTREE
-      if (EARTH->options->treeprint == LASTCHAIN)
-	{
-	  FPRINTF(EARTH->treefile,"#NEXUS\n\nbegin trees;");
-	}
-#endif
-
-#ifdef PTHREADS
-    tpool_init (&heating_pool, usize, usize, 0);
-#endif
-    
-    if (options->heating)
-        //first in universe is the cold chain[EARTH]
-        heating_init (universe, usize, data, options);
-    getseed (options);
-    //#ifdef MPI
-    //    MYMPIBARRIER(comm_world);
-    //#endif
-    /* calculate FST values */
-#ifdef MPI
-    if(myID!=MASTER)
-      {
-	if(options->printfst || options->thetaguess==FST || options->migrguess==FST)
-	  {
-	    calc_simple_param (EARTH, data);
-	  }
-      }
-#endif
-    /* report to screen */
-    if (myID == MASTER)
+  if (EARTH->options->treeprint == LASTCHAIN)
     {
-        print_menu_options (EARTH, options, data);
-        if (options->progress)
-            print_data_summary (stdout, EARTH, options, data);
-        /* print to outfile */
-#ifdef PRETTY
-  pdf_master_init(EARTH, options, data);
-#endif 
-        *outfilepos = print_title (EARTH, options);
-        print_options (EARTH->outfile, EARTH, options, data);
-        print_data_summary (EARTH->outfile, EARTH, options, data);
-        print_data (EARTH, options, data);
-        print_spectra (EARTH, options, data);
-
-	if(options->bayes_infer && myID == MASTER)
-	  {
-	    if(options->has_bayesmdimfile)
-	      print_bayes_mdimfileheader(EARTH->bayesmdimfile,
-					 options->bayesmdiminterval, EARTH, data);
-	  }
+      FPRINTF(EARTH->treefile,"#NEXUS\n\nbegin trees;");
     }
-    if (options->lchains < 2 && options->replicatenum == 0)
-        options->replicate = 0;
-    maxreplicate = (options->replicate
-                    && options->replicatenum > 0) ? options->replicatenum : 1;
+#endif
+  
+#ifdef PTHREADS
+  tpool_init (&heating_pool, usize, usize, 0);
+#endif
+  
+  if (options->heating)
+    {
+      //first in universe is the cold chain[EARTH]
+      heating_init (universe, usize, data, options);
+    }
+  getseed (options);
+  /* calculate FST values */
+#ifdef MPI
+  if(myID!=MASTER)
+    {
+      if(options->printfst || options->thetaguess==FST || options->migrguess==FST)
+	{
+	  calc_simple_param (EARTH, data);
+	}
+    }
+#endif
+  /* report to screen */
+  if (myID == MASTER)
+    {
+      print_menu_options (EARTH, options, data);
+      if (options->progress)
+	print_data_summary (stdout, EARTH, options, data);
+      /* print to outfile */
+#ifdef PRETTY
+      pdf_master_init(EARTH, options, data);
+#endif 
+      *outfilepos = print_title (EARTH, options);
+      print_options (EARTH->outfile, EARTH, options, data);
+      print_data_summary (EARTH->outfile, EARTH, options, data);
+      print_data (EARTH, options, data);
+      print_spectra (EARTH, options, data);
+      
+      if(options->bayes_infer && myID == MASTER)
+	{
+	  if(options->has_bayesmdimfile)
+	    print_bayes_mdimfileheader(EARTH->bayesmdimfile,
+				       options->bayesmdiminterval, EARTH, data);
+	}
+    }
+  if (options->lchains < 2 && options->replicatenum == 0)
+    {
+      options->replicate = 0;
+    }
+  maxreplicate = (options->replicate
+		  && options->replicatenum > 0) ? options->replicatenum : 1;
 #ifdef MPI
     minnodes = MAX (0, numcpu - data->loci - 1);
     irequests = (MPI_Request *) mycalloc (minnodes + 1, sizeof (MPI_Request));
     istatus = (MPI_Status *) mycalloc (minnodes + 1, sizeof (MPI_Status));
     if (myID == MASTER)
-    {
-      mpi_runloci_master (data->loci, EARTH->who, EARTH, options->readsum, options->menu);
+      {
+	mpi_runloci_master (data->loci, EARTH->who, EARTH, options->readsum, options->menu);
 #ifndef MPIREPLICANT
-        sent = mpi_send_stop_mcmc_worker (numcpu, data->loci, &comm_world, irequests,istatus, myID);
-
-
+        //sent = mpi_send_stop_mcmc_worker (numcpu, data->loci, &comm_world, irequests,istatus, myID);
 #endif
     }
     else
@@ -1515,8 +1503,8 @@ setup_locus (long locus, world_fmt * world, option_fmt * options,
   //  printf(" fixed times \n");
 #endif
   first_smooth (world, locus);
-  world->likelihood[0] = -MYREAL_MAX; //treelikelihood (world);
-  world->allikemax = -MYREAL_MAX;	/* for best tree option */
+  world->likelihood[0] = treelikelihood (world);
+  world->allikemax = world->likelihood[0]; //-MYREAL_MAX;	/* for best tree option */
   world->treelen = 0.0;
   calc_treelength (world->root->next->back, &world->treelen);
 #ifdef UEP
@@ -1684,7 +1672,6 @@ heating_prepare (world_fmt ** universe, int usize,
     for (chain = 1; chain < usize; ++chain)
       {
 	buildtree (universe[chain], options, data, EARTH->locus);//DEBUG
-
         klone (EARTH, universe[chain], options, data, options->heat[chain]);
       }
 }
@@ -2280,12 +2267,12 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   //  MYREAL sum = 0.;
   MYREAL heat0 = 1.;
   MYREAL heat1 = 1.;
+  MYREAL val0  = 0.;
+  MYREAL val1  = 0.;
   MYREAL bfsum = 0.;
-#ifdef NEWVERSION
   MYREAL bfsum2 = 0.;
   MYREAL approxlsum = 0.;
   MYREAL intercept = 0.;
-#endif
   MYREAL hsum = 0.;
   MYREAL asum = 0.;
   MYREAL lsum;
@@ -2300,6 +2287,14 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	    continue;
 
 	  lsum = 0.;
+#ifdef MPI
+	  // the thermodynamic integration is reporting maxreplicate times too high values
+	  // warning("this should fix the thermodynamic/mpi/replicate  problem, but needs to be checked for multilocus data");
+	  for(t=0; t < hc; t++)
+	    {
+	      EARTH->bf[locus * hc + t] /= maxreplicate;
+	    }
+#endif
 	  for(t=1; t < hc; t++)
 	    {
 #ifdef MPI
@@ -2317,8 +2312,11 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 		  heat1 = universe[t]->heat;
 		}
 #endif
-	      lsum += (heat0 - heat1) * ((EARTH->bf[locus * hc + t-1] + EARTH->bf[locus * hc + t]) * 0.5);
-#ifdef NEWVERSION
+	      //Simpson's rule and trapezoidal are the same when I do only have function values at a and b
+	      val0 = EARTH->bf[locus * hc + t-1];
+	      val1 = EARTH->bf[locus * hc + t];
+	      lsum += (heat0 - heat1) * (val0 + val1) * 0.5;
+#ifdef DEBUG
 	      printf("%i> sum[%li]=%f temp=(%f %f) values=(%f %f)\n",myID,t,lsum,heat0,heat1,EARTH->bf[locus * hc + t-1],EARTH->bf[locus * hc + t]);
 #endif
 	    }
@@ -2328,18 +2326,18 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	  // this is certainly rough, but in simulations with 3 populations one can see that with large number
 	  // of temperatures this looks reasonable, and one can approximate the integral more accurately with 
 	  // with only a few columns.
-#ifdef NEWVERSION
 	  intercept = (heat0 * EARTH->bf[locus * hc + t-1] - heat1 * EARTH->bf[locus * hc + t-2])/(heat0 - heat1);
 	  approxlsum = lsum + heat1 * ((EARTH->bf[locus * hc + t-1] + intercept) * 0.5);
-
+#ifdef DEBUG
 	  fprintf(stdout,"Thermo[%li]=%f (%f) [%f]\n",locus, lsum, approxlsum, intercept);
+#endif
 	  //	  bfsum += log(lsum) + EARTH->bfscale[locus];
 	  bfsum2 += approxlsum;
-#endif
+
 	  bfsum += lsum; //+ EARTH->bfscale[locus];
 	}
 #ifdef NEWVERSION
-      fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f (%f) %s\n", bfsum, bfsum2,  
+      fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f (%f with approximation) %s\n", bfsum, bfsum2,  
       	      options->adaptiveheat ? "(adaptive heating -> value may be wrong)" : "");
 #else
       fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f %s\n", bfsum,  
