@@ -6,7 +6,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
     mighistogram   R O U T I N E S that use less memory
 
     Peter Beerli 2006, Tallahassee
-    beerli@scs.fsu.edu
+    beerli@fsu.edu
 
     Copyright 2006 Peter Beerli, Tallahassee
 
@@ -482,7 +482,7 @@ void print_event_values_tofile(FILE *file,  world_fmt *world)
     fprintf(file,"# produced by the program %s (http://popgen.scs.fsu.edu/migrate.hml)\n",
             MIGRATEVERSION);  
     fprintf(file,"# written by Peter Beerli 2006-2007, Tallahassee,\n");
-    fprintf(file,"# if you have problems with this file please email to beerli@scs.fsu.edu\n");  
+    fprintf(file,"# if you have problems with this file please email to beerli@fsu.edu\n");  
     fprintf(file,"#\n");
     fprintf(file,"# Order of the parameters:\n");
     fprintf(file,"# Parameter-number Parameter\n");
