@@ -8,7 +8,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
     variation over time routines   R O U T I N E S
 
     Peter Beerli 2006, Tallahassee
-    beerli@scs.fsu.edu
+    beerli@fsu.edu
 
     Copyright 2006 Peter Beerli, Tallahassee
 
