@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1331 2008-07-31 18:55:29Z beerli $
+$Id: tools.c 1444 2008-10-18 14:04:48Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -607,8 +607,6 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 		if (!options->readsum)
 		{
 			openfile (&data->infile, options->infilename, "r+",  NULL);
-			if (options->treeprint > 0)
-				openfile (&world->treefile, options->treefilename, "w+",  NULL);
 			if (options->usertree)
 				openfile (&data->utreefile, options->utreefilename, "r+",  NULL);
 			if (options->weights)
@@ -630,6 +628,15 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 #ifdef MPI
 		setup_filehandle_db((void *) world->outfile, world, options,data);
 #endif
+
+		if (options->treeprint > 0 && (!options->readsum))
+		  {
+		    openfile (&world->treefile, options->treefilename, "w+",  NULL);
+#ifdef MPI
+		    setup_filehandle_db((void *) world->treefile, world, options,data);
+#endif
+		  }
+
 		if (options->mighist)
 		  {
 			openfile (&world->mighistfile, options->mighistfilename, "w+", NULL);
@@ -735,6 +742,8 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 		//assumess same order as in the master
 		j=1; //zero is stdout
 		world->outfile = filedb[j++].file;
+		if (options->treeprint > 0 && (!options->readsum))
+		  world->treefile = filedb[j++].file;
 		if (options->mighist)
 			world->mighistfile = filedb[j++].file;
 		if (options->skyline)
@@ -1182,6 +1191,7 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
         read_geofile (data, options, world->numpop);
         data->numpop = world->numpop;
         set_plot (options);
+	world->cold=TRUE;
         init_world (world, data, options);
         ta = world->atl;
         for (l = 0; l < world->loci; l++)
@@ -1323,8 +1333,10 @@ write_savesum (world_fmt * world)
         for (r = 0; r < repmax; r++)
         {
             fprintf (sumfile,
-                     "%li %li ####### locus %li, replicate %li ################\n%li %li %li\n",
-                     l, r, l, r, ta[r][l].T, ta[r][l].numpop, ta[r][l].sumtips);
+                     "%li %li ####### locus %li, replicate %li ################\n",
+                     l, r, l, r);
+	    fprintf(sumfile,"%li %li %li\n",ta[r][l].T, ta[r][l].numpop, ta[r][l].sumtips);
+
             fprintf (sumfile, "%20.20g %20.20g %20.20g\n", ta[r][l].param_like,
                      ta[r][l].thb, ta[r][l].alpha);
             for (i = 0; i < ta[r][l].T; i++)
@@ -1944,7 +1956,7 @@ lu_decomp (MYREAL **m, long *indeks, long nrows)
 /* needs first the evaluation LU decomposition           */
 /* Syntax: lu_substition(matrix, indeks, vector, nrows)   */
 /* matrix = LU decomposed matrix, indeks = order of matrix */
-/* vector = value vevtor, nrows = number of rows/columns */
+/* vector = value vector, nrows = number of rows/columns */
 /* april 95 PB                                           */
 void
 lu_substitution (MYREAL **m, long *indeks, MYREAL *v, long nrows)
